% data = vid_capture(time);
%
%   Rob Stead August 19 2010
%
% This function depends on capture_op.m, used to
% control the video capture card.
%
% This function simply collects frames for the specified amount of time (in
% seconds).
%
% This program should be called with the motor stage centered
% on the region of interest.
%

function data = vid_capture(time)

% Defines
window_dim = [10 10]; % Region of interest integration size
frame_rate = 30; % Specifies a frame rate of 30 frames per second
disp('Initializing capture card...')
v = capture_op(0, 'init');

% Region select
im = capture_op(v, 'snap');
fig = figure;
imshow(im);
disp('USER: select a region for FTS sampling.')
region = ginput(1);
close(fig);
capture_op(v, 'window', [region window_dim]);
pause(0.5);

total_time = time;

% Capture at least the right number of frames
n_frames = (total_time - 1) * frame_rate;
disp(['Capturing ' num2str(n_frames) ' frames...'])
capture_op(v, 'start');
capture_op(v, 'frame_count', n_frames);
capture_op(v, 'stop');

% Get them, average them
data = capture_op(v, 'frames', n_frames);
data = squeeze(sum(sum(data)));

disp('Cleaning up...')
capture_op(v, 'cleanup');

end
